==> samurai-graph-src-1.0.0.zip: samurai-graph-src-1.0.0/src/jp/riken/brain/ni/samuraigraph/figure/SGIStringConstants.java <==

package jp.riken.brain.ni.samuraigraph.figure;

import java.awt.Color;
import java.awt.Font;

import jp.riken.brain.ni.samuraigraph.base.SGIAxisElement;
import jp.riken.brain.ni.samuraigraph.base.SGIDrawingElementConstants;


/**
 * Constants for labels.
 */
public interface SGIStringConstants extends SGIDrawingElementConstants
{
	
	public static final double STRING_ANGLE_MIN = -180.0;
	public static final double STRING_ANGLE_MAX = 180.0;


	public static final String TAG_NAME_LABEL = "Label";

	
	// location
	public static final String KEY_X = "X";
	public static final String KEY_Y = "Y";
	public static final String KEY_ANGLE = "Angle";
	

	// font
	public static final String KEY_TEXT = "Text";
	public static final String KEY_FONT_SIZE = "FontSize";
	public static final String KEY_FONT_NAME = "FontName";
	public static final String KEY_FONT_STYLE = "FontStyle";
	public static final String KEY_STRING_COLORS = "StringColor";

	
	public static final String KEY_X_VALUE = "XValue";
	public static final String KEY_Y_VALUE = "YValue";



	//
	// Default values
	//

	// Font
	public static final String DEFAULT_LABEL_FONT_NAME = "Serif";
	public static final int DEFAULT_LABEL_FONT_STYLE = Font.PLAIN;
	public static final float DEFAULT_LABEL_FONT_SIZE = 16.0f;

	// Color
	public static final Color DEFAULT_LABEL_FONT_COLOR= Color.BLACK;

	// Angle
	public static final float DEFAULT_LABEL_ANGLE = 0.0f;
	
	// Horizontal Axis
	public static final String DEFAULT_LABEL_HORIZONTAL_AXIS = SGIAxisElement.AXIS_BOTTOM;
	
	// Perpendicular Axis
	public static final String DEFAULT_LABEL_PERPENDICULAR_AXIS = SGIAxisElement.AXIS_LEFT;

}

==> samurai-graph-src-1.0.5.zip: samurai-graph-src-1.0.5/src/jp/riken/brain/ni/samuraigraph/figure/SGIStringConstants.java <==

package jp.riken.brain.ni.samuraigraph.figure;

import java.awt.Color;
import java.awt.Font;

import jp.riken.brain.ni.samuraigraph.base.SGIFigureElementAxis;
import jp.riken.brain.ni.samuraigraph.base.SGIDrawingElementConstants;


/**
 * Constants for labels.
 */
public interface SGIStringConstants extends SGIDrawingElementConstants
{
	
	public static final double STRING_ANGLE_MIN = -180.0;
	public static final double STRING_ANGLE_MAX = 180.0;


	public static final String TAG_NAME_LABEL = "Label";

	
	// location
	public static final String KEY_X = "X";
	public static final String KEY_Y = "Y";
	public static final String KEY_ANGLE = "Angle";
	

	// font
	public static final String KEY_TEXT = "Text";
	public static final String KEY_FONT_SIZE = "FontSize";
	public static final String KEY_FONT_NAME = "FontName";
	public static final String KEY_FONT_STYLE = "FontStyle";
	public static final String KEY_STRING_COLORS = "StringColor";

	
	public static final String KEY_X_VALUE = "XValue";
	public static final String KEY_Y_VALUE = "YValue";



	//
	// Default string values
	//
	public static final String DEFAULT_STRING_FONT_NAME = "Serif";
	public static final int DEFAULT_STRING_FONT_STYLE = Font.PLAIN;
	public static final float DEFAULT_STRING_FONT_SIZE = 16.0f;
	public static final Color DEFAULT_STRING_FONT_COLOR= Color.BLACK;
	public static final float DEFAULT_STRING_ANGLE = 0.0f;

	//
	// Label
	//
	public static final String DEFAULT_LABEL_FONT_NAME = "Serif";
	public static final int DEFAULT_LABEL_FONT_STYLE = Font.PLAIN;
	public static final float DEFAULT_LABEL_FONT_SIZE = 16.0f;
	public static final Color DEFAULT_LABEL_FONT_COLOR= Color.BLACK;
	public static final float DEFAULT_LABEL_ANGLE = 0.0f;

	// Horizontal Axis
	public static final String DEFAULT_LABEL_HORIZONTAL_AXIS = SGIFigureElementAxis.AXIS_BOTTOM;
	
	// Perpendicular Axis
	public static final String DEFAULT_LABEL_PERPENDICULAR_AXIS = SGIFigureElementAxis.AXIS_LEFT;

}
